==> igniteui-react-charts-18.5.0-beta.0.tgz: package/esm5/lib/EaseOfMovementIndicator.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { StrategyBasedIndicator } from "./StrategyBasedIndicator";
import { EaseOfMovementIndicatorStrategy } from "./EaseOfMovementIndicatorStrategy";
import { markType } from "igniteui-react-core";
/**
 * @hidden
 */
var EaseOfMovementIndicator = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(EaseOfMovementIndicator, _super);
    function EaseOfMovementIndicator() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    EaseOfMovementIndicator.prototype.get_yy = function () {
        return new EaseOfMovementIndicatorStrategy();
    };
    Object.defineProperty(EaseOfMovementIndicator.prototype, "yy", {
        get: function () {
            return this.get_yy();
        },
        enumerable: false,
        configurable: true
    });
    EaseOfMovementIndicator.prototype.get_zb = function () {
        return EaseOfMovementIndicator.$;
    };
    Object.defineProperty(EaseOfMovementIndicator.prototype, "zb", {
        get: function () {
            return this.get_zb();
        },
        enumerable: false,
        configurable: true
    });
    EaseOfMovementIndicator.$t = markType(EaseOfMovementIndicator, 'EaseOfMovementIndicator', StrategyBasedIndicator.$);
    return EaseOfMovementIndicator;
}(StrategyBasedIndicator));
export { EaseOfMovementIndicator };

==> igniteui-react-charts-18.7.4-beta.0.tgz: package/esm5/lib/EaseOfMovementIndicator.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { StrategyBasedIndicator } from "./StrategyBasedIndicator";
import { EaseOfMovementIndicatorStrategy } from "./EaseOfMovementIndicatorStrategy";
import { markType } from "igniteui-react-core";
/**
 * @hidden
 */
var EaseOfMovementIndicator = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(EaseOfMovementIndicator, _super);
    function EaseOfMovementIndicator() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    EaseOfMovementIndicator.prototype.bj = function () {
        return new EaseOfMovementIndicator();
    };
    EaseOfMovementIndicator.prototype.get_abq = function () {
        return new EaseOfMovementIndicatorStrategy();
    };
    Object.defineProperty(EaseOfMovementIndicator.prototype, "abq", {
        get: function () {
            return this.get_abq();
        },
        enumerable: false,
        configurable: true
    });
    EaseOfMovementIndicator.prototype.get_ab3 = function () {
        return EaseOfMovementIndicator.$;
    };
    Object.defineProperty(EaseOfMovementIndicator.prototype, "ab3", {
        get: function () {
            return this.get_ab3();
        },
        enumerable: false,
        configurable: true
    });
    EaseOfMovementIndicator.$t = markType(EaseOfMovementIndicator, 'EaseOfMovementIndicator', StrategyBasedIndicator.$);
    return EaseOfMovementIndicator;
}(StrategyBasedIndicator));
export { EaseOfMovementIndicator };
